@@ -79,9 +79,10 @@ class Andor3():
         
         # If that didn't work, try some other common locations
         if self._dll is None and platform.system() == "Windows":
-            for loc in (os.path.join(os.environ["ProgramFiles"], "Andor Driver Pack 3"),
+            for loc in (os.path.join(os.environ["ProgramFiles"], "Andor SDK3"),
+                        os.path.join(os.environ["ProgramFiles"], "Andor Driver Pack 3"),
                         os.path.join(os.environ["ProgramFiles"], "Andor SOLIS"),
-                        os.path.join(os.environ["ProgramFiles"], "National Instruments", "LabVIEW")):    
+                        os.path.join(os.environ["ProgramFiles"], "National Instruments", "LabVIEW")):
                 try:
                     _log.debug(f"Searching for Andor3 library in {loc}...")
                     self._dll = cdll.LoadLibrary(os.path.join(loc, libname))
