@@ -27,7 +27,7 @@ documented here which will choose the appropriate implementation for you.
 __all__ = ["unpack_uint12", "fvb", "fvb_images", "decode_image_data", "decode_image_with_metadata", "decode_metadata", "FrameServer", "FrameDump"]
 
 import logging
-from threading import Thread, Event
+import threading
 import struct
 from time import monotonic, sleep
 
@@ -396,7 +396,7 @@ class FrameServer():
     def __init__(self, cam, frame_callback, completion_callback=None, fvb=False, frame_rate_max=None):
         self._cam = cam
         self._thread = None
-        self._thread_stop = Event()
+        self._thread_stop = threading.Event()
         if callable(frame_callback):
             self._frame_callback = frame_callback
         else:
@@ -436,7 +436,7 @@ class FrameServer():
         if frame_rate_max is not None:
             self._frame_interval = 1.0/frame_rate_max if frame_rate_max else 0.0
         self._thread_stop.clear()
-        self._thread = Thread(target=self._run, name="Andor3_FrameServer", daemon=True)
+        self._thread = threading.Thread(target=self._run, name="Andor3_FrameServer", daemon=True)
         self._thread.start()
 
     def stop(self):
@@ -445,7 +445,7 @@ class FrameServer():
         """
         self._thread_stop.set()
         # Wait for thread to finish
-        if self._thread and self._thread.is_alive():
+        if self._thread and self._thread.is_alive() and not self._thread == threading.current_thread():
             self._thread.join()
 
     def _run(self):
@@ -515,7 +515,7 @@ class FrameDump():
     def __init__(self, cam, completion_callback, fvb=False):
         self._cam = cam
         self._thread = None
-        self._thread_stop = Event()
+        self._thread_stop = threading.Event()
         if callable(completion_callback):
             self._completion_callback = completion_callback
         else:
@@ -545,7 +545,7 @@ class FrameDump():
         if fvb is not None:
             self._fvb = bool(fvb)
         self._thread_stop.clear()
-        self._thread = Thread(target=self._run, args=(n_images,), name="Andor3_FrameDump", daemon=True)
+        self._thread = threading.Thread(target=self._run, args=(n_images,), name="Andor3_FrameDump", daemon=True)
         self._thread.start()
 
     def stop(self):
@@ -554,7 +554,7 @@ class FrameDump():
         """
         self._thread_stop.set()
         # Wait for thread to finish
-        if self._thread and self._thread.is_alive():
+        if self._thread and self._thread.is_alive() and not self._thread == threading.current_thread():
             self._thread.join() 
 
     def _run(self, frame_count_max):
